==> safe_network-0.27.6.crate: safe_network-0.27.6/src/client/README.md <==
# sn_client

| [![](http://meritbadge.herokuapp.com/sn_client)](https://crates.io/crates/sn_client) | [![Documentation](https://docs.rs/sn_client/badge.svg)](https://docs.rs/sn_client) |
|:----------:|:----------:|

## Compatability

`sn_node`: 0.42.X

## Overview

`sn_client` can interface conditionally against either the sn_routing crate or a mock used for local testing.

## Crate Dependencies
Crate dependencies graph:

![sn_client Safe Network dependencies](https://github.com/maidsafe/sn_client/blob/png_generator/sn_client-sn-dependencies.png)


### Legend
Dependencies are coloured depending on their kind:
* **Black:** regular dependency
* **Purple:** build dependency
* **Blue:** dev dependency
* **Red:** optional dependency

A dependency can be of more than one kind. In such cases, it is coloured with the following priority:
`Regular -> Build -> Dev -> Optional`

<details>
<summary> View all sn_client dependencies</summary>
<p>

![sn_client all dependencies](https://github.com/maidsafe/sn_client/blob/png_generator/sn_client-all-dependencies.png)

</p>
</details>

Click [here](https://maidsafe.github.io/interdependency-svg-generator/) for an overview of the interdependencies of all the main MaidSafe components.

## License

This Safe Network library is licensed under the General Public License (GPL), version 3 ([LICENSE](LICENSE) http://www.gnu.org/licenses/gpl-3.0.en.html).

### Linking exception

sn_client is licensed under GPLv3 with linking exception. This means you can link to and use the library from any program, proprietary or open source; paid or gratis. However, if you modify sn_client, you must distribute the source to your modified version under the terms of the GPLv3.

See the [LICENSE](LICENSE) file for more details.

==> safe_network-0.52.2.crate: safe_network-0.52.2/src/client/README.md <==
# sn_client

| [![](https://img.shields.io/crates/v/sn_client)](https://crates.io/crates/sn_client) | [![Documentation](https://docs.rs/sn_client/badge.svg)](https://docs.rs/sn_client) |
|:----------:|:----------:|

## Compatability

`sn_node`: 0.42.X

## Overview

`sn_client` can interface conditionally against either the sn_routing crate or a mock used for local testing.

## Crate Dependencies
Crate dependencies graph:

![sn_client Safe Network dependencies](https://github.com/maidsafe/sn_client/blob/png_generator/sn_client-sn-dependencies.png)


### Legend
Dependencies are coloured depending on their kind:
* **Black:** regular dependency
* **Purple:** build dependency
* **Blue:** dev dependency
* **Red:** optional dependency

A dependency can be of more than one kind. In such cases, it is coloured with the following priority:
`Regular -> Build -> Dev -> Optional`

<details>
<summary> View all sn_client dependencies</summary>
<p>

![sn_client all dependencies](https://github.com/maidsafe/sn_client/blob/png_generator/sn_client-all-dependencies.png)

</p>
</details>

Click [here](https://maidsafe.github.io/interdependency-svg-generator/) for an overview of the interdependencies of all the main MaidSafe components.

## License

This Safe Network library is licensed under the General Public License (GPL), version 3 ([LICENSE](LICENSE) http://www.gnu.org/licenses/gpl-3.0.en.html).

### Linking exception

sn_client is licensed under GPLv3 with linking exception. This means you can link to and use the library from any program, proprietary or open source; paid or gratis. However, if you modify sn_client, you must distribute the source to your modified version under the terms of the GPLv3.

See the [LICENSE](LICENSE) file for more details.
